@@ -1,3 +1,8 @@
+"""
+Schedule
+========
+"""
+
 from deepcrawl.utils import ImmutableAttributesMixin
 from deepcrawl.utils import safe_string_to_datetime
 
@@ -20,6 +25,9 @@ schedule_fields = schedule_mutable_attributes + schedule_immutable_attributes
 
 
 class DeepCrawlSchedule(ImmutableAttributesMixin):
+    """
+    Schedule class
+    """
     __slots__ = schedule_fields
 
     mutable_attributes = schedule_mutable_attributes
@@ -41,3 +49,9 @@ class DeepCrawlSchedule(ImmutableAttributesMixin):
         self._href = schedule_data.get("_href")
 
         super(DeepCrawlSchedule, self).__init__()
+
+    def __repr__(self):
+        return f"[{self.account_id} {self.project_id} {self.id}] {self.next_run_time}"
+
+    def __str__(self):
+        return f"[{self.account_id} {self.project_id} {self.id}] {self.next_run_time}"
