@@ -1,3 +1,8 @@
+"""
+Extractions
+===========
+"""
+
 from deepcrawl.utils import ImmutableAttributesMixin
 
 extraction_mutable_fields = (
@@ -11,6 +16,9 @@ extraction_mutable_fields = (
 
 
 class DeepCrawlExtraction(ImmutableAttributesMixin):
+    """
+    Extractions class
+    """
     __slots__ = extraction_mutable_fields
 
     mutable_attributes = extraction_mutable_fields
