@@ -1,5 +1,9 @@
-from deepcrawl.utils import ImmutableAttributesMixin
+"""
+Majestic Settings
+=================
+"""
 
+from deepcrawl.utils import ImmutableAttributesMixin
 
 majestic_mutable_fields = (
     'enabled',
@@ -13,11 +17,13 @@ majestic_immutable_fields = (
     '_href'
 )
 
-
 majestic_fields = majestic_mutable_fields + majestic_immutable_fields
 
 
 class MajesticSettings(ImmutableAttributesMixin):
+    """
+    Majestic settings class
+    """
     __slots__ = majestic_fields
 
     mutable_attributes = majestic_mutable_fields
