@@ -1,4 +1,13 @@
+"""
+ReportRow
+=========
+"""
+
+
 class DeepCrawlReportRow:
+    """
+    Report row class
+    """
     def __init__(self, account_id, project_id, crawl_id, report_id, row_data: dict):
 
         # relations
